@@ -1,13 +1,13 @@
 #!/usr/bin/env python3
 
 import logging
-from datetime import datetime  # maybe use udatetime
-from uuid import uuid4  # maybe use fastuuid (incompatible with PyPy)
+from datetime import datetime
+from uuid import uuid4
 
 from box import Box
 
 _l = logging.getLogger(__name__)
-# stop = False
+stop = False
 
 
 class Message:
@@ -44,11 +44,8 @@ class Message:
     def __setitem__(self, name, value):
         self.__data[name] = value
 
-    def __repr__(self):
-        return f'<{self.__class__.__name__} {self.meta.id} {self.get("file") or self.get("path")}>'
-
     def __str__(self):
-        return f'<{self.__class__.__name__} {self.meta.id} {self.get("file") or self.get("path")}>'
+        return f'<{self.__class__.__name__} {self.meta.id}>'
 
     def checkin(self, component):
         self._tag(component, 'in')
@@ -66,32 +63,9 @@ class Message:
 
     def drop(self, component):
         self._tag(component, 'dropped')
-        try:
-            del self._instances[self.meta.id]
-        except IndexError:
-            raise IndexError(f'Dropped message does not exist: {self}')
-
+        del self._instances[self.meta.id]
         self.meta.dropped = True
-        if 'streams' in self.meta:
-            for stream in self.meta.streams.copy().values():
-                stream.remove(self)
         component.debug(f'Dropped message: {self}')
 
     def _tag(self, component, tag):
         self.meta.history.append((datetime.utcnow(), component.id, tag))
-
-    # def deepget(self, mapping, key):
-    #     if '.' not in key:
-    #         return mapping[key]
-    #
-    #     else:
-    #         current, remainder = key.split('.', 1)
-    #         return self.deepget(mapping[current], remainder)
-    #
-    # def deepset(self, mapping, key, value):
-    #     if '.' not in key:
-    #         mapping[key] = value
-    #
-    #     else:
-    #         current, remainder = key.split('.', 1)
-    #         self.deepset(mapping[current], remainder, value)
